Enum Trovs
#[repr(u8)]pub enum Trovs {
Automatic = 0,
Triggered = 1,
}Variants
Automatic = 0
All oversampled conversions for a channel are run following a trigger
Triggered = 1
Each oversampled conversion for a channel needs a new trigger
Implementations